/*-------------------------------------------------------------------------+
| Copyright 2023 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.ext.quality.data;

/**
 * 
 * @author groh
 */
public enum MetricKey {

	//
	// Metrics provided by the HierarchicElementProvider
	//
	/** Unique ID of the element */
	UNQIUE_ID,

	/** Key for the metric counting ports */
	NUMBER_OF_CONNECTORS,
	/** Key for the metric counting elements */
	NUMBER_OF_CONTAINED_ELEMENTS,
	/** Key for the metric counting channels */
	NUMBER_OF_CHANNELS,

	// Metrics which are collected over all children nodes
	/** Key for the metric counting the total amount of ports contained */
	NUMBER_OF_TOTAL_CONNECTORS,
	/** Key for the metric counting the total amount of input ports contained */
	NUMBER_OF_TOTAL_ENTRY_CONNECTORS,
	/** Key for the metric counting the total amount of output ports contained */
	NUMBER_OF_TOTAL_EXIT_CONNECTORS,
	/** Key for the metric counting the total amount of elements contained */
	NUMBER_OF_TOTAL_ELEMENTS,
	/** Key for the metric counting the total amount of elements which can be commented */
	NUMBER_OF_TOTAL_COMMENTABLE_ELEMENTS,
	/** Key for the metric counting the total amount of elements which are commented */
	NUMBER_OF_TOTAL_COMMENTED_ELEMENTS,
	/**
	 * Key for the metric counting the total amount of elements which do not contain other elements
	 */
	NUMBER_OF_TOTAL_LEAF_ELEMENTS,
}
